==> gammaray_2.4.0.orig.tar.xz: gammaray-2.4.0/core/singlecolumnobjectproxymodel.cpp <==
/*
  singlecolumnobjectproxymodel.h

  This file is part of GammaRay, the Qt application inspection and
  manipulation tool.

  Copyright (C) 2010-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
  Author: Volker Krause <volker.krause@kdab.com>

  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
  accordance with GammaRay Commercial License Agreement provided with the Software.

  Contact info@kdab.com if any conditions of this licensing are not clear to you.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "singlecolumnobjectproxymodel.h"

#include <core/util.h>
#include <common/objectmodel.h>

using namespace GammaRay;

SingleColumnObjectProxyModel::SingleColumnObjectProxyModel(QObject *parent) :
    QIdentityProxyModel(parent)
{
}

int SingleColumnObjectProxyModel::columnCount(const QModelIndex& parent) const
{
    return std::min(QIdentityProxyModel::columnCount(parent), 1);
}

QVariant SingleColumnObjectProxyModel::data(const QModelIndex &proxyIndex, int role) const
{
    if (proxyIndex.isValid() && role == Qt::DisplayRole && proxyIndex.column() == 0) {
        const QObject *obj = proxyIndex.data(ObjectModel::ObjectRole).value<QObject*>();
        if (obj) {
            return Util::displayString(obj);
        }
    }

    return QIdentityProxyModel::data(proxyIndex, role);
}

==> gammaray_2.6.0.orig.tar.xz: gammaray-2.6.0/core/singlecolumnobjectproxymodel.cpp <==
/*
  singlecolumnobjectproxymodel.h

  This file is part of GammaRay, the Qt application inspection and
  manipulation tool.

  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
  Author: Volker Krause <volker.krause@kdab.com>

  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
  accordance with GammaRay Commercial License Agreement provided with the Software.

  Contact info@kdab.com if any conditions of this licensing are not clear to you.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "singlecolumnobjectproxymodel.h"

#include <core/util.h>
#include <common/objectmodel.h>

using namespace GammaRay;

SingleColumnObjectProxyModel::SingleColumnObjectProxyModel(QObject *parent)
    : QIdentityProxyModel(parent)
{
}

int SingleColumnObjectProxyModel::columnCount(const QModelIndex &parent) const
{
    return std::min(QIdentityProxyModel::columnCount(parent), 1);
}

QVariant SingleColumnObjectProxyModel::data(const QModelIndex &proxyIndex, int role) const
{
    if (proxyIndex.isValid() && role == Qt::DisplayRole && proxyIndex.column() == 0) {
        const QObject *obj = proxyIndex.data(ObjectModel::ObjectRole).value<QObject *>();
        if (obj)
            return Util::displayString(obj);
    }

    return QIdentityProxyModel::data(proxyIndex, role);
}
